@@ -182,22 +182,22 @@
     <message>
         <location filename="../dde-osd/src/osdprovider.cpp" line="125"/>
         <source>WLAN on</source>
-        <translation>WLAN hapur</translation>
+        <translation>WLAN i hapur</translation>
     </message>
     <message>
         <location filename="../dde-osd/src/osdprovider.cpp" line="126"/>
         <source>WLAN off</source>
-        <translation>WLAN mbyllur</translation>
+        <translation>WLAN i mbyllur</translation>
     </message>
     <message>
         <location filename="../dde-osd/src/osdprovider.cpp" line="128"/>
         <source>Caps Lock on</source>
-        <translation>Shkronja të mëdha aktive</translation>
+        <translation>Caps Lock aktiv</translation>
     </message>
     <message>
         <location filename="../dde-osd/src/osdprovider.cpp" line="129"/>
         <source>Caps Lock off</source>
-        <translation>Shkronja të vogla joaktive</translation>
+        <translation>Caps Lock joaktiv</translation>
     </message>
     <message>
         <location filename="../dde-osd/src/osdprovider.cpp" line="131"/>
@@ -247,7 +247,7 @@
     <message>
         <location filename="../dde-osd/src/osdprovider.cpp" line="146"/>
         <source>Balanced power</source>
-        <translation type="unfinished"/>
+        <translation>Energji i balancuar</translation>
     </message>
     <message>
         <location filename="../dde-osd/src/osdprovider.cpp" line="147"/>
@@ -281,7 +281,7 @@
         <location filename="../reset-password-dialog/passwordwidget.cpp" line="57"/>
         <location filename="../reset-password-dialog/passwordwidget.cpp" line="146"/>
         <source>Passwords do not match</source>
-        <translation>Fjalëkalimet nuk përputhen</translation>
+        <translation>Fjalëkalimet s’përputhen</translation>
     </message>
     <message>
         <location filename="../reset-password-dialog/passwordwidget.cpp" line="65"/>
@@ -351,7 +351,7 @@
     <message>
         <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="49"/>
         <source>Cancel</source>
-        <translation>Anuloje</translation>
+        <translation>Anulojeni</translation>
     </message>
     <message>
         <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="51"/>
